//----------------------------------------------------------------------------
//----------------------------------------------------------------------------
// This example shows the use of SS940Control DLL from under Visual Studio C++
//----------------------------------------------------------------------------
/*********************************************************************
 * SS940ControlTest 
 * 07-Nov-2005
 * Users may use, copy or modify <Project Name> according to the AC 
 * Technoogy Inc., copyright below.
 *
 *********************************************************************/
/*
 * This file is provided for unrestricted use provided that this legend is included on all
 * media and as a part of the software program in whole or part.  Users
 * may copy or modify this file without charge, but are not authorized
 * to license or distribute it to anyone else except as part of a product or
 * program developed by the user.
 * 
 * THIS CODE  PROVIDED AS IS WITH NO WARRANTIES OF ANY KIND 
 * INCLUDING THE WARRANTIES OF DESIGN, MERCHANTIBILITY AND 
 * FITNESS FOR A PARTICULAR PURPOSE, OR ARISING FROM A COURSE 
 * OF DEALING, USAGE OR TRADE PRACTICE.
 
 * This code is provided with no support and without any obligation on the
 * part of AC Technology, Inc. to assist in its use, correction, modification or 
 * enhancement.
 * 
 *AC TECHNOLOGY, INC. SHALL HAVE NO LIABILITY WITH RESPECT 
 * TO THE INFRINGEMENT OF COPYRIGHTS, TRADE SECRETS OR ANY
 * PATENTS BY AC TECHNOLOGY ,INC. OR ANY PART THEREOF.
 * 
 * In no event will AC Technology, Inc. be liable for any lost revenue
 * or profits or other special, indirect and consequential damages, even if
 * AC Technology, Inc. has been advised of the possibility of such damages.
 * 
 * AC Technology, Inc.
 * 660 Douglas St.,
 * Uxbridge, MA
 *
 * Copyright (C) 2002-2005, AC Technology, Inc.
 */









#include "stdio.h"
#include "stdlib.h"

#include "windows.h"

#include "SS940API.h"
#include "paramid.h"
//#include "paramid.h"

//----------------------------------------------------------------------------

#define SERROR() if(res!=EC_OK) { printf( "ERROR: Command at line %d failed. Error code [%d]\r\n", __LINE__, res ); exit(res); }

//----------------------------------------------------------------------------
//                                                               MoveDistance
//----------------------------------------------------------------------------

void MoveDistance( SHANDLE h, double d )
{
	double	value;
	int	status, res;

	res = SS940_SetParamAsDouble  ( h, PID_UNITS,  1  ); SERROR()
	res = SS940_SetParamAsInteger ( h, PID_ACCEL,  20 ); SERROR()
	res = SS940_SetParamAsDouble  ( h, PID_DECEL,  10 ); SERROR()
	res = SS940_SetParamAsDouble  ( h, PID_MAXVEL, 20 ); SERROR()
	res = SS940_SetParamAsInteger ( h, PID_ENABLE, 1  ); SERROR()
	res = SS940_SetParamAsDouble  ( h, PID_MOVED,  d  ); SERROR()

	do {
		res = SS940_GetParamAsDouble( h, PID_APOS, value ); SERROR()
		printf( "Current position %8.4f  \r", value );
		res = SS940_GetParamAsInteger( h, PID_STATUS, status ); SERROR()
	} while ( !(status & 0x02000000) ); // MotionComplete flag

	Sleep( 500 );

	res = SS940_GetParamAsDouble( h, PID_APOS, value ); SERROR()
	printf( "Current position %8.4f  \r", value );
	res = SS940_SetParamAsInteger ( h, PID_ENABLE, 0  ); SERROR()
	printf( "\nMove completed\r\n\r\n" );
}

//----------------------------------------------------------------------------
//                                                         MoveWhileInputOpen
//----------------------------------------------------------------------------

void MoveWhileInputOpen( SHANDLE h, long in )
{
	double	value;
	int	status, res;
/*
	res = SS940_SetParamAsDouble  ( h, PID_UNITS,      1 ); SERROR()
	res = SS940_SetParamAsInteger ( h, PID_ACCEL,     10 ); SERROR()
	res = SS940_SetParamAsDouble  ( h, PID_DECEL,     30 ); SERROR()
	res = SS940_SetParamAsDouble  ( h, PID_MAXVEL,    30 ); SERROR()
	res = SS940_SetParamAsInteger ( h, PID_ENABLE,     1 ); SERROR()
	res = SS940_SetParamAsInteger ( h, PID_MOVE_PWI0, in ); SERROR()
*/	
	long	ids[] =    { PID_UNITS, PID_ACCEL, PID_DECEL, PID_MAXVEL, PID_ENABLE, PID_MOVE_PWI0 };
	double  params[] = {         1,        10,        30,         30,          1,            in };

	res = SS940_SetArrayAsDouble ( h, ids, params, sizeof(ids)/sizeof(long) ); SERROR()

	do {
		res = SS940_GetParamAsDouble( h, PID_APOS, value ); SERROR()
		printf( "Current position %8.4f  \r", value );
		res = SS940_GetParamAsInteger( h, PID_STATUS, status ); SERROR()
	} while ( !(status & 0x02000000) ); // MotionComplete flag

	Sleep( 500 );

	res = SS940_GetParamAsDouble( h, PID_APOS, value ); SERROR()
	printf( "Current position %8.4f  \r", value );
	res = SS940_SetParamAsInteger ( h, PID_ENABLE, 0  ); SERROR()
	printf( "\nMove completed\r\n\r\n" );
}

//----------------------------------------------------------------------------
//                                                                       Main
//----------------------------------------------------------------------------

int __cdecl main( int argc, char* argv[] )
{
	BYTE		ip[]  =        { 192,168,124,120 };
	BYTE		ba[]  =        { 255,255,255,255 };
	BYTE		ip_serial[] =  { 127,  0,  0,  1 };		// to connect through serial with device # 1
	BYTE		ipn[4];
	BYTE		sern[4];
	char*		name = "Kuku-1";
	SHANDLE		udph, broadcast;
	long		res, v, vlist[4], delta, cor;

	printf( "\r\n" );
	printf( "                                               AC Technology (C) 2002-2005\r\n" );
	printf( "                                               Simple Servo\r\n" );
	printf( "                                               SS940 control over interface\r\n" );
	printf( "          SS940Control.dll demonstration\r\n" );
	printf( "                                               Created by  Nikolai Romanov\r\n" );
	printf( "                                               nromanov@actech.com\r\n\r\n" );

	//-----------------------------------------------------------------------
	// Check DLL version and exercise 'find by name' capabilities
	//-----------------------------------------------------------------------

		printf( "SS940Control DLL Version %d found\r\n\r\n", GetDllVersion() );

		if ( SS940_FindByName ( name, ipn, sern, 3000 ) != 1 ) {
			printf( "Failed to locate drive with name: %s\n", name );
		} else {
			printf( "Drive with name %s reported IP %d.%d.%d.%d, ser %d.%d\n", name, ipn[0], ipn[1], ipn[2], ipn[3], sern[3], sern[0] );
		}

	//-----------------------------------------------------------------------
	// First try to connect to drive through EtherNet
	//-----------------------------------------------------------------------

		udph = SS940_OpenInterfaceB( ip, 3000 );
		if ( !udph ) { printf( "Failed to open UDP interface\r\n" ); exit( 0 ); }

		printf( "Executing 'MoveWhileInput' A4 over Ethernet\r\n" );
		MoveWhileInputOpen( udph, 3 );
		Sleep( 100 );
		
		printf( "Executing 'MoveD 110.5' over Ethernet\r\n" );
		MoveDistance( udph, 110.5 );
		Sleep( 100 );

		SS940_CloseInterface( udph );

	//-----------------------------------------------------------------------
	// Now connect through serial port
	//-----------------------------------------------------------------------

		if ( SS940_EnableSerialInterface( 1, 115200 ) != EC_OK )
		{ printf( "Failed to open COM port 1\r\n" ); exit( 0 ); }

		udph = SS940_OpenInterfaceB( ip_serial, 3000 );
		if ( !udph ) { printf( "Failed to open interface. IP configuration problems\r\n" ); exit( 0 ); }

		printf( "Executing 'MoveWhileInput' A4 over serial line\r\n" );
		MoveWhileInputOpen( udph, 3 );
		Sleep( 100 );
		
		printf( "Executing 'MoveD 110.5' over serial line\r\n" );
		MoveDistance( udph, 110.5 );
		Sleep( 100 );

		SS940_CloseInterface( udph );

		SS940_DisableSerialInterface();
	
	//-----------------------------------------------------------------------

	return 1;
}

//----------------------------------------------------------------------------
//----------------------------------------------------------------------------
      